%   Binary Top-Hat Beam shaping: nominal and post-tolerance simulation
%     binaryTH(nominalStruct,toleranceStruct)
%  
%   The input variables include two structures: 
%     nominalStruct - parameters for nominal simulation
%     toleranceStruct - parameters after tolerances 
%     Fields of each structure:
%         nominalStruct.CA - clear aperture size in mm
%         nominalStruct.beamDia - Gaussian beam diameter at exp(-2) in mm
%         nominalStruct.f - Effective Focal Length (EFL) of the system in mm
%         nominalStruct.lambda  laser wavelength in mm (i.e, 500nm=5e-4)
%         nominalStruct.shape  shape string: 'square', 'round' or 'line'
%         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%         toleranceStruct.tolvariable_string - variable for tolerances. Options: 'defocus', 'wavelength', 'beamSizeChange', 'decenter'
%         toleranceStruct.tolvar_values - values for tolerances in mm. It is possible to run several  tolerance values in each run using []
%  
%     Examples:
%  
%             nominalStruct.CA = 23.6;
%             nominalStruct.beamDia = 5;
%             nominalStruct.f = 100;
%             nominalStruct.lambda = 0.532e-3;
%             nominalStruct.shape = 'square';
%             toleranceStruct.tolvariable_string = 'defocus'; % options: 'defocus', 'wavelength', 'beamSizeChange', 'decenter'
%             toleranceStruct.tolvar_values = [-1 -0.5 0 0.5 1]; % enter values in mm
%             binaryTH(nominalStruct,toleranceStruct);
% 
%     This algorithm uses an analytical model for binary Top-Hats.
%     Holo/Or also offers further optimization of simulation parameters.
%  
%     For more information see: <a href= "matlab: web http://www.holoor.co.il/Diffractive_optics_Applications/Application_Notes_BeamShapers.htm -browser">Top-Hat's application note on HOLOOR Website</a>
%  
% 
%
